import { select, tsv, geoPath, 
        geoNaturalEarth1, zoom, event,
       scaleOrdinal, schemeSpectral} from 'd3';
import {feature} from 'topojson';
import {loadAndProcessData} from './loadAndProcess.js'
import { colorLegend } from './colorLegend.js'

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const projection = geoNaturalEarth1();
const pathGenerator = geoPath().projection(projection);

const g = svg.append('g');

g.append('path')
		.attr('class', 'sphere')
		.attr('d', pathGenerator({type: 'Sphere'}));

const colorLegendG = svg.append('g')
		.attr('transform', `translate(40, ${height -200})`)

svg.call(zoom().on('zoom', () => {
		g.attr('transform', event.transform);
		}));

const colorScale = scaleOrdinal(schemeSpectral[7]);

const colorValue = d => d.properties.economy;

loadAndProcessData().then(countries => {
  
  		colorScale
        		.domain(countries.features.map(colorValue))
  					.domain(colorScale.domain().sort().reverse())
  					.range(schemeSpectral[colorScale.domain().length]);
  
  		colorLegendG.call(colorLegend, {
  		colorScale,
  		circleR : 60,
  		spacing: 30,
   		textOff: 30 
      BgWidth: 300;
      });

  
  		g.selectAll('path')
          .data(countries.features)
          .enter().append('path')
            .attr('class', 'country')
            .attr('d', pathGenerator)
  					.attr('fill', d => colorScale(colorValue(d)))
          .append('title')
            .text( d => d.properties.name + ':' + colorValue(d))
});


	









